==> tutti-ui-swing-2.5.1-sources.jar: fr/ifremer/tutti/ui/swing/util/table/AbstractSelectTableAction.java <==
package fr.ifremer.tutti.ui.swing.util.table;

/*
 * #%L
 * Tutti :: UI
 * $Id: AbstractSelectTableAction.java 135 2013-01-01 16:10:44Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.5.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/util/table/AbstractSelectTableAction.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.swing.AbstractAction;
import javax.swing.JTable;

/**
 * Abstract action to select something in a table.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.2
 */
public abstract class AbstractSelectTableAction<M extends AbstractTuttiTableModel> extends AbstractAction {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(AbstractSelectTableAction.class);

    public static void doSelectCell(JTable table,
                                    int rowIndex,
                                    int columnIndex) {

        table.setColumnSelectionInterval(columnIndex, columnIndex);
        table.setRowSelectionInterval(rowIndex, rowIndex);
        table.editCellAt(rowIndex, columnIndex);
    }

    private final M model;

    private final JTable table;

    public AbstractSelectTableAction(M model, JTable table) {
        this.model = model;
        this.table = table;
    }

    protected void doSelectCell(int rowIndex, int columnIndex) {

        if (log.isDebugEnabled()) {
            log.debug("Will select cell at " +
                      getCellCoordinate(rowIndex, columnIndex));
        }
        doSelectCell(table, rowIndex, columnIndex);
    }

    protected int getSelectedRow() {
        int result = table.getSelectedRow();
        return result;
    }

    protected int getSelectedColumn() {
        int result = table.getSelectedColumn();
        return result;
    }

    protected int getRowCount() {
        return table.getRowCount();
    }

    protected int getColumnCount() {
        return table.getColumnCount();
    }

    protected boolean isCellEditable(int rowIndex, int columnIndex) {
        boolean result;
        result = rowIndex > -1 && columnIndex > -1 &&
//                 rowIndex < getRowCount() && columnIndex < getColumnCount() &&
                 table.isCellEditable(rowIndex, columnIndex);
        return result;
    }

    protected boolean isCreateNewRow() {
        return model.isCreateNewRow();
    }

    protected String getCellCoordinate(int rowIndex, int columnIndex) {
        return " [" + rowIndex + ", " + columnIndex + "]";
    }

    protected void addNewRow() {
        model.addNewRow();
    }
}

==> tutti-ui-swing-2.6-sources.jar: fr/ifremer/tutti/ui/swing/util/table/AbstractSelectTableAction.java <==
package fr.ifremer.tutti.ui.swing.util.table;

/*
 * #%L
 * Tutti :: UI
 * $Id: AbstractSelectTableAction.java 135 2013-01-01 16:10:44Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.6/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/util/table/AbstractSelectTableAction.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.swing.AbstractAction;
import javax.swing.JTable;

/**
 * Abstract action to select something in a table.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.2
 */
public abstract class AbstractSelectTableAction<M extends AbstractTuttiTableModel> extends AbstractAction {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(AbstractSelectTableAction.class);

    public static void doSelectCell(JTable table,
                                    int rowIndex,
                                    int columnIndex) {

        table.setColumnSelectionInterval(columnIndex, columnIndex);
        table.setRowSelectionInterval(rowIndex, rowIndex);
        table.editCellAt(rowIndex, columnIndex);
    }

    private final M model;

    private final JTable table;

    public AbstractSelectTableAction(M model, JTable table) {
        this.model = model;
        this.table = table;
    }

    protected void doSelectCell(int rowIndex, int columnIndex) {

        if (log.isDebugEnabled()) {
            log.debug("Will select cell at " +
                      getCellCoordinate(rowIndex, columnIndex));
        }
        doSelectCell(table, rowIndex, columnIndex);
    }

    protected int getSelectedRow() {
        int result = table.getSelectedRow();
        return result;
    }

    protected int getSelectedColumn() {
        int result = table.getSelectedColumn();
        return result;
    }

    protected int getRowCount() {
        return table.getRowCount();
    }

    protected int getColumnCount() {
        return table.getColumnCount();
    }

    protected boolean isCellEditable(int rowIndex, int columnIndex) {
        boolean result;
        result = rowIndex > -1 && columnIndex > -1 &&
//                 rowIndex < getRowCount() && columnIndex < getColumnCount() &&
                 table.isCellEditable(rowIndex, columnIndex);
        return result;
    }

    protected boolean isCreateNewRow() {
        return model.isCreateNewRow();
    }

    protected String getCellCoordinate(int rowIndex, int columnIndex) {
        return " [" + rowIndex + ", " + columnIndex + "]";
    }

    protected void addNewRow() {
        model.addNewRow();
    }
}
